from mdt import CompartmentTemplate

__author__ = 'Robbert Harms'
__date__ = "2015-06-21"
__maintainer__ = "Robbert Harms"
__email__ = "robbert@xkls.nl"


class Dot(CompartmentTemplate):

    parameters = ()
    cl_code = 'return 1.0;'
